**vandal** 

![vandal-header](https://raw.githubusercontent.com/dkundih/vandal/master/.logistics/visforvandalpy.jpg)

vandal is now an archived package, while all of it's functionality has been merged into the duality package.

**duality**

![duality-header](https://raw.githubusercontent.com/dkundih/duality/main/.logistics/duality.jpg)

- due to multiple requests to make vandal alive, it now fetches the functionality of the newest duality package as a temporary solution.

visit https://pypi.org/project/duality/ or https://github.com/dkundih/duality for more details.
